@@ -11,7 +11,11 @@
 #' @description \code{xegaReRun()} runs a simple genetic algorithm with 
 #'              the same configuration as in the run specified by the 
 #'              list element \code{$GAconfig} of the solution of 
-#'              a simple genetic algorithm.
+#'              a simple genetic algorithm. The problem environment and the 
+#'              the grammar are extracted from the solution object.
+#'
+#'              If \code{script==TRUE}, the \code{solution} object and a R script 
+#'              to rerun xega are written to the current directory.
 #'
 #' @details \code{xegaReRun()} does not capture the configuration for 
 #'          parallel/distributed processing for the execution model
@@ -24,6 +28,10 @@
 #'
 #' @param  solution  The solution of a 
 #'                   previous run of \code{xegaRun()}.
+#' @param  script    Boolean. Default: FALSE. 
+#'                   If TRUE, write an R script to repeat the xega run
+#'                   with the command in the solution object.
+#' @param  fn        Filename of R script. Default: xegaRunScript.R
 #'
 #' @return A list of 
 #'         \enumerate{
@@ -64,12 +72,38 @@
 #' b<-xegaReRun(c)
 #'
 #' @export
-xegaReRun<-function(solution)
+xegaReRun<-function(solution, script=FALSE, fn="xegaRunScript")
 { 
-if (!is.null(solution$GAenv$uParApply)) 
-{warning("Error: Re-run of configuration with a user supplied parallel apply not supported."); return(solution)}
-if (!(solution$GAenv$executionModel %in% c("Sequential", "MultiCore"))) 
-{warning("Error: Re-run of parallel or distributed configurations not possible."); return(solution)}
-eval(parse(text=solution$GAconfig)) 
+z<-solution$GAconfig[[1]]
+#i1<-gregexpr("penv=", z)
+#e1<-i1[[1]]+attr(i1[[1]], "match.length")-1
+#nz<-substring(z, 1, e1)
+nz<-paste0("xegaRun(solution$GAenv$penv,grammar=solution$GAenv$grammar")
+i1<-gregexpr(",max=", z)
+s1<-i1[[1]]
+rest<-substring(z, s1, nchar(z))
+nz<-paste0(nz, rest)
+
+if (script)
+{
+sfn<-paste0(fn, "solution.rds")
+rfn<-paste0(fn,".R")
+saveRDS(solution, file=sfn)
+nz<-paste0("r<-",nz)
+nz<-paste0("\n library(xega) \n solution<-readRDS(file=\"", 
+           sfn, "\" ) \n\n", nz)
+nz<-gsub(",", ",\n    ", nz)
+writeLines(nz, con=rfn)
+
+return(solution)
 }
 
+if (!is.null(solution$GAenv$uParApply)) 
+{warning("Error: Re-run of configuration with a user supplied parallel apply not supported."); return(solution)}
+if (!(solution$GAenv$executionModel %in% c("Sequential", "MultiCore", "MultiCoreHet"))) 
+{warning("Error: Re-run of parallel or distributed configurations not possible."); return(solution)}
+
+eval(parse(text=nz)) 
+}
+
+
